@@ -13,16 +13,14 @@ from future import standard_library
 standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA: #402
 
 dfaceid_t = Struct(
-    'hammerFaceID' / Int16ul
+    'hammerFaceID' / Int16ul * "index into :ref:`lump 27<lump_27>`",
 )
 
 
+@lump_array
+@lump_version(0)
 def lump_11(header, profile=None):
-    if header.version != 0:
-        raise LumpVersionUnsupportedError(header.version)
-    return lump_array(LUMP_FACEIDS, dfaceid_t, header)
+    return dfaceid_t
