@@ -13,8 +13,6 @@ from future import standard_library
 standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA: #402
 
 
@@ -22,13 +20,13 @@ dmodel_t = Struct(
     'mins' / Vector * 'lower point of the bounding box',
     'maxs' / Vector * 'higher point the bounding box',
     'origin' / Vector,
-    'headnode' / Int32sl * 'index into node array',
-    'firstface' / Int32sl * 'index into face array',
+    'headnode' / Int32sl * 'index into :ref:`lump 5<lump_5>`',
+    'firstface' / Int32sl * 'index into :ref:`lump 7<lump_7>`',
     'numfaces' / Int32sl
 )
 
 
+@lump_array
+@lump_version(0)
 def lump_14(header, profile=None):
-    if header.version != 0:
-        raise LumpVersionUnsupportedError(header.version)
-    return lump_array(LUMP_MODELS, dmodel_t, header)
+    return dmodel_t
