@@ -13,18 +13,16 @@ from future import standard_library
 standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA: #402
 
 dbrush_t = Struct(
-    'firstSide' / Int32sl,
+    'firstSide' / Int32sl * "index into :ref:`lump 19<lump_19>`",
     'numSides' / Int32sl,
     'contents' / Int32sl,
 )
 
 
+@lump_array
+@lump_version(0)
 def lump_18(header, profile=None):
-    if header.version != 0:
-        raise LumpVersionUnsupportedError(header.version)
-    return lump_array(LUMP_BRUSHES, dbrush_t, header)
+    return dbrush_t
