@@ -15,31 +15,28 @@ from future import standard_library
 standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA: #402
 
 dbrushside_t_P2 = Struct(
     'planeNum' / Int16ul,
-    'texInfo' / Int16sl,
-    'dispInfo' / Int16sl,
+    'texInfo' / Int16sl * "index into :ref:`lump 6<lump_6>`",
+    'dispInfo' / Int16sl * "index into :ref:`lump 26<lump_26>`",
     'bevel' / Int8sl,
     'thin' / Int8sl
 )
 
 dbrushside_t = Struct(
     'planeNum' / Int16ul,
-    'texInfo' / Int16sl,
-    'dispInfo' / Int16sl,
+    'texInfo' / Int16sl * "index into :ref:`lump 6<lump_6>`",
+    'dispInfo' / Int16sl * "index into :ref:`lump 26<lump_26>`",
     'bevel' / Int16sl
 )
 
 
+@lump_array
+@lump_version(0)
 def lump_19(header, profile=None):
-    if header.version == 0:
-        if profile in [ALIENSWARM, PORTAL2]:
-            return lump_array(LUMP_BRUSHSIDES, dbrushside_t_P2, header)
-        else:
-            return lump_array(LUMP_BRUSHSIDES, dbrushside_t, header)
+    if profile in [ALIENSWARM, PORTAL2]:
+        return dbrushside_t_P2
     else:
-        raise LumpVersionUnsupportedError(header.version)
+        return dbrushside_t
