@@ -13,17 +13,15 @@ from future import standard_library
 standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA: #402
 
 darea_t = Struct(
     'numAreaPortals' / Int32sl,
-    'firstAreaPortal' / Int32sl
+    'firstAreaPortal' / Int32sl * "index into :ref:`lump 21<lump_21>`"
 )
 
 
+@lump_array
+@lump_version(0)
 def lump_20(header, profile=None):
-    if header.version != 0:
-        raise LumpVersionUnsupportedError(header.version)
-    return lump_array(LUMP_AREAS, darea_t, header)
+    return darea_t
