@@ -2,7 +2,7 @@
 Lump 22 - Portals ...or Prop Collision
 ======================================
 
-This lump is not currently implemented. It will return the raw bytes.
+|lump_not_implemented|
 """
 
 from __future__ import absolute_import
@@ -13,12 +13,10 @@ from future import standard_library
 standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA: #402
 
 
+@lump_raw
+@lump_version(0)
 def lump_22(header, profile=None):
-    if header.version != 0:
-        raise LumpVersionUnsupportedError(header.version)
-    return lump_bytes(LUMP_UNUSED0, header)
+    return
