@@ -13,13 +13,11 @@ from future import standard_library
 standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA #402
 from valvebsp.structs.lump_7 import dface_t  # NOQA #402
 
 
+@lump_array
+@lump_version(0)
 def lump_27(header, profile=None):
-    if header.version != 0:
-        raise LumpVersionUnsupportedError(header.version)
-    return lump_array(LUMP_ORIGINALFACES, dface_t, header)
+    return dface_t
