@@ -13,12 +13,10 @@ from future import standard_library
 standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA #402
 
 
+@lump_array
+@lump_version(0)
 def lump_34(header, profile=None):
-    if header.version != 0:
-        raise LumpVersionUnsupportedError(header.version)
-    return lump_array(LUMP_DISP_LIGHTMAP_SAMPLE_POSITIONS, Int8ul, header)
+    return Int8ul
