@@ -13,13 +13,15 @@ from future import standard_library
 standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA #402
 
+dgamelump_flags = FlagsEnum(
+    Int16ul,
+    GAMELUMPFLAG_COMPRESSED=1)
+
 dgamelump_t = Struct(
     'id' / PaddedString(4, "ascii"),
-    'flags' / Int16ul,
+    'flags' / dgamelump_flags,
     'version' / Int16ul,
     'fileofs' / Int32sl,
     'filelen' / Int32sl,
@@ -31,7 +33,7 @@ dgamelumpheader_t = Struct(
 )
 
 
+@lump_struct
+@lump_version(0)
 def lump_35(header, profile=None):
-    if header.version != 0:
-        raise LumpVersionUnsupportedError(header.version)
-    return lump_struct(LUMP_GAME_LUMP, dgamelumpheader_t, header)
+    return dgamelumpheader_t
