@@ -2,7 +2,7 @@
 Lump 4 - Visibility
 ===================
 
-This lump is not currently implemented. It will return the raw bytes.
+|lump_not_implemented|
 """
 
 from __future__ import division
@@ -13,8 +13,6 @@ from future import standard_library
 standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA: #402
 
 '''
@@ -25,7 +23,7 @@ dvis_t = Struct(
 '''
 
 
+@lump_raw
+@lump_version(0)
 def lump_4(header, profile=None):
-    if header.version != 0:
-        raise LumpVersionUnsupportedError(header.version)
-    return lump_bytes(LUMP_VISIBILITY, header)
+    return
