@@ -2,7 +2,7 @@
 Lump 40 - Pakfile
 =================
 
-This lump contains raw data. the data can be saved directly to the disc as a zip file.
+This lump contains raw data. The data can be saved directly to the disc as a zip file.
 """
 
 from __future__ import absolute_import
@@ -12,12 +12,10 @@ from __future__ import unicode_literals
 from future import standard_library
 standard_library.install_aliases()
 
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA #402
 
 
+@lump_raw
+@lump_version(0)
 def lump_40(header, profile=None):
-    if header.version != 0:
-        raise LumpVersionUnsupportedError(header.version)
-    return lump_bytes(LUMP_PAKFILE, header)
+    return
