@@ -12,12 +12,10 @@ from __future__ import unicode_literals
 from future import standard_library
 standard_library.install_aliases()
 
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA: #402
 
 
+@lump_array
+@lump_version(0)
 def lump_41(header, profile=None):
-    if header.version != 0:
-        raise LumpVersionUnsupportedError(header.version)
-    return lump_array(LUMP_CLIPPORTALVERTS, Vector, header)
+    return Vector
