@@ -13,13 +13,11 @@ from future import standard_library
 standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA #402
 
 doverlay_t = Struct(
     'id' / Int32sl,
-    'texInfo' / Int16sl,
+    'texInfo' / Int16sl * "index into :ref:`lump 6<lump_6>`",
     'faceCountAndRenderOrder' / Int16ul,
     'faces' / Int32sl[OVERLAY_BSP_FACE_COUNT],
     'u' / Float32l[2],
@@ -30,7 +28,7 @@ doverlay_t = Struct(
 )
 
 
+@lump_array
+@lump_version(0)
 def lump_45(header, profile=None):
-    if header.version != 0:
-        raise LumpVersionUnsupportedError(header.version)
-    return lump_array(LUMP_OVERLAYS, doverlay_t, header)
+    return doverlay_t
