@@ -11,8 +11,6 @@ from future import standard_library
 standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA #402
 
 dnode_t = Aligned(4, Struct(
@@ -20,13 +18,13 @@ dnode_t = Aligned(4, Struct(
     'children' / Int32sl[2],
     'mins' / Int16sl[3],
     'maxs' / Int16sl[3],
-    'firstFace' / Int16ul,
+    'firstFace' / Int16ul * 'index into :ref:`lump 7<lump_7>`',
     'numFaces' / Int16ul,
     'area' / Int16sl,
 ))
 
 
+@lump_array
+@lump_version(0)
 def lump_5(header, profile=None):
-    if header.version != 0:
-        raise LumpVersionUnsupportedError(header.version)
-    return lump_array(LUMP_NODES, dnode_t, header)
+    return dnode_t
