@@ -13,20 +13,16 @@ from future import standard_library
 standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA: #402
 
 dleafambientindex_t = Struct(  # matches dleaf_t
     'ambientSampleCount' / Int16ul,
-    'firstAmbientSample' / Int16ul
+    'firstAmbientSample' / Int16ul * \
+    "index into :ref:`lump 55<lump_55>` or :ref:`lump 56<lump_56>`",
 )
 
 
+@lump_array
+@lump_version([0, 1])
 def lump_51(header, profile=None):
-    if header.version == 0:
-        return lump_array(LUMP_LEAF_AMBIENT_INDEX_HDR, dleafambientindex_t, header)
-    elif header.version == 1:
-        return lump_array(LUMP_LEAF_AMBIENT_INDEX_HDR, dleafambientindex_t, header)
-    else:
-        raise LumpVersionUnsupportedError(header.version)
+    return dleafambientindex_t
