@@ -13,14 +13,10 @@ from __future__ import unicode_literals
 from future import standard_library
 standard_library.install_aliases()
 
-from construct import *  # NOQA: #402
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA: #402
 
 
+@lump_array
+@lump_version([0, 1])
 def lump_53(header, profile=None):
-    if header.version in [0, 1]:
-        return lump_array(LUMP_LIGHTING_HDR, ColorRGBExp32, header)
-    else:
-        raise LumpVersionUnsupportedError(header.version)
+    return ColorRGBExp32
