@@ -13,8 +13,6 @@ from future import standard_library
 standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA #402
 
 dleafambientlighting_t = Aligned(4, Struct(
@@ -25,16 +23,15 @@ dleafambientlighting_t = Aligned(4, Struct(
 ))
 
 
+@lump_array
 def lump_56(header, profile=None):
     if header.version == 1:
-        return lump_array(LUMP_LEAF_AMBIENT_LIGHTING,
-                          dleafambientlighting_t, header)
+        return dleafambientlighting_t
 
     elif header.version == header.filelen:
         # This is obviously a mistake in the bsp header, let's assume v1
         # (seen in css map once)
-        return lump_array(LUMP_LEAF_AMBIENT_LIGHTING,
-                          dleafambientlighting_t, header)
+        return dleafambientlighting_t
 
     else:
         raise LumpVersionUnsupportedError(header.version)
