@@ -13,14 +13,17 @@ from future import standard_library
 standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA #402
 
-flags_t = Struct('levelFlags' / Int32ul)
+flags_flags = FlagsEnum(
+    Int32ul,
+    BAKED_STATIC_PROP_LIGHTING_NONHDR=1,
+    BAKED_STATIC_PROP_LIGHTING_HDR=2)
+
+flags_t = Struct('levelFlags' / flags_flags)
 
 
+@lump_struct
+@lump_version(0)
 def lump_59(header, profile=None):
-    if header.version != 0:
-        raise LumpVersionUnsupportedError(header.version)
-    return lump_struct(LUMP_MAP_FLAGS, flags_t, header)
+    return flags_t
