@@ -13,33 +13,30 @@ from future import standard_library
 standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA: #402
 
 dface_t = Struct(
     'planenum' / Int16ul,
     'side' / Byte,
     'onNode' / Byte,
-    'firstedge' / Int32sl,
+    'firstedge' / Int32sl * "index into :ref:`lump 13<lump_13>`",
     'numedges' / Int16sl,
     'texinfo' / Int16sl,
     'dispinfo' / Int16sl,
     'surfaceFogVolumeID' / Int16sl,
     'styles' / Byte[4],
-    'lightofs' / Int32sl,
+    'lightofs' / Int32sl * "index into :ref:`lump 8<lump_8>`",
     'area' / Float32l,
     'lightmapTextureMinsInLuxels' / Int32sl[2],
     'lightmapTextureSizeInLuxels' / Int32sl[2],
-    'origFace' / Int32sl,
+    'origFace' / Int32sl * "index into :ref:`lump 11<lump_11>`",
     'numPrims' / Int16ul,
-    'firstPrimID' / Int16ul,
+    'firstPrimID' / Int16ul * "index into :ref:`lump 37<lump_37>`",
     'smoothingGroups' / Int32ul,
 )
 
 
+@lump_array
+@lump_version([0, 1])
 def lump_7(header, profile=None):
-    if header.version in [0, 1]:
-        return lump_array(LUMP_FACES, dface_t, header)
-    else:
-        raise LumpVersionUnsupportedError(header.version)
+    return dface_t
