@@ -13,12 +13,14 @@ from future import standard_library
 standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA: #402
 
+doccluderdata_flags = FlagsEnum(
+    Int32sl,
+    OCCLUDER_FLAGS_INACTIVE=1)
+
 doccluderdata_t = Struct(
-    'flags' / Int32sl,
+    'flags' / doccluderdata_flags,
     'firstPoly' / Int32sl,
     'polyCount' / Int32sl,
     'mins' / Vector,
@@ -42,8 +44,7 @@ doccluder_t = Struct(
 )
 
 
+@lump_struct
+@lump_version(2)
 def lump_9(header, profile=None):
-    if header.version == 2:
-        return lump_struct(LUMP_OCCLUSION, doccluder_t, header)
-    else:
-        raise LumpVersionUnsupportedError(header.version)
+    return doccluder_t
