@@ -12,15 +12,11 @@ from __future__ import unicode_literals
 from future import standard_library
 standard_library.install_aliases()
 
-from construct import *  # NOQA: #402
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA #402
 from valvebsp.structs.lump_tlpd import DetailPropLightStylesLump_t  # NOQA #402
 
 
+@lump_struct
+@lump_version(0)
 def lump_hlpd(header, profile=None):
-    if header.version != 0:
-        raise LumpVersionUnsupportedError(header.version)
-
-    return lump_game('hlpd', DetailPropLightStylesLump_t, header)
+    return DetailPropLightStylesLump_t
