@@ -13,8 +13,6 @@ from future import standard_library
 standard_library.install_aliases()
 
 from construct import *  # NOQA: #402
-from valvebsp.constants import *  # NOQA: #402
-from valvebsp.exceptions import *  # NOQA: #402
 from valvebsp.structs.common import *  # NOQA: #402
 
 DetailPropLightStyleLump_t = Struct(
@@ -28,8 +26,7 @@ DetailPropLightStylesLump_t = Struct(
 )
 
 
+@lump_struct
+@lump_version(0)
 def lump_tlpd(header, profile=None):
-    if header.version != 0:
-        raise LumpVersionUnsupportedError(header.version)
-
-    return lump_game('tlpd', DetailPropLightStylesLump_t, header)
+    return DetailPropLightStylesLump_t
